@@ -23,11 +23,7 @@ def logger(important_params=None, output_file=None):
             else:
                 output_line = "Executing function: [" + func.__name__ + "] Called by: [" + calframe[1][3] + "]" + "- Result: " + str(result)
             
-            if not output_file:
-                with open(output_file, "w") as file:
-                    file.write(output_line + '\n')
-            else:
-                print(output_line)
+            print(output_line)
             
             return result
         return inner
